@@ -52,7 +52,7 @@ auto SimplexArgs = r::List::create(
     r::_["columns"]         = std::string(""),
     r::_["target"]          = std::string(""),
     r::_["embedded"]        = false,
-    r::_["const_predict"]   = false,
+    //r::_["const_predict"]   = false, // Rcpp 20 arg limit
     r::_["verbose"]         = false,
     r::_["validLib"]        = std::vector<bool>(),
     r::_["generateSteps"]   = 0,
@@ -75,12 +75,14 @@ auto SMapArgs = r::List::create(
     r::_["exclusionRadius"] = 0,
     r::_["columns"]         = std::string(""),
     r::_["target"]          = std::string(""),
-    r::_["smapFile"]        = std::string(""),
-    //r::_["jacobians"]     = std::string(""), // Rcpp 20 arg limit
+    //r::_["smapCoefFile"]  = std::string(""), // Rcpp 20 arg limit
+    //r::_["smapSVFile"]    = std::string(""), // Rcpp 20 arg limit
+    //r::_["solver"]        = std::string(""), // Not supported by glmnet
     r::_["embedded"]        = false,
-    r::_["const_predict"]   = false,
+    //r::_["const_predict"] = false,           // Rcpp 20 arg limit
     r::_["verbose"]         = false,
     r::_["validLib"]        = std::vector<bool>(),
+    r::_["ignoreNan"]       = true,
     r::_["generateSteps"]   = 0,
     //r::_["generateLibrary"] = false, // Rcpp 20 arg limit
     r::_["parameterList"]   = false );
@@ -124,7 +126,7 @@ auto CCMArgs = r::List::create(
     r::_["libSizes"]        = std::string(""),
     r::_["sample"]          = 0,
     r::_["random"]          = true,
-    r::_["replacement"]     = false,
+    //r::_["replacement"]   = false,             // Rcpp 20 arg limit
     r::_["seed"]            = 0,
     r::_["embedded"]        = false,
     r::_["includeData"]     = false,
