@@ -98,12 +98,13 @@ SMapValues SMap( std::string pathIn          = "./data/",
                  int         exclusionRadius = 0,
                  std::string columns         = "",
                  std::string target          = "",
-                 std::string smapFile        = "",
-                 std::string derivatives     = "",
+                 std::string smapCoefFile    = "",
+                 std::string smapSVFile      = "",
                  bool        embedded        = false,
                  bool        const_predict   = false,
                  bool        verbose         = true,
                  std::vector<bool> validLib  = std::vector<bool>(),
+                 bool        ignoreNan       = true,
                  int         generateSteps   = 0,
                  bool        generateLibrary = false,
                  bool        parameterList   = false );
@@ -123,11 +124,12 @@ SMapValues SMap( DataFrame< double > &dataFrameIn,
                  std::string columns         = "",
                  std::string target          = "",
                  std::string smapFile        = "",
-                 std::string derivatives     = "",
+                 std::string smapSVFile      = "",
                  bool        embedded        = false,
                  bool        const_predict   = false,
                  bool        verbose         = true,
                  std::vector<bool> validLib  = std::vector<bool>(),
+                 bool        ignoreNan       = true,
                  int         generateSteps   = 0,
                  bool        generateLibrary = false,
                  bool        parameterList   = false );
@@ -148,19 +150,18 @@ SMapValues SMap( std::string pathIn          = "./data/",
                  std::string columns         = "",
                  std::string target          = "",
                  std::string smapFile        = "",
-                 std::string derivatives     = "",
-                 std::valarray< double > (*solver)
-                     (DataFrame     < double >,
-                      std::valarray < double >) = & SVD,
+                 std::string smapSVFile      = "",
+                 SVDValues  (*solver) (DataFrame     < double >,
+                                       std::valarray < double >) = & SVD,
                  bool        embedded        = false,
                  bool        const_predict   = false,
                  bool        verbose         = true,
                  std::vector<bool> validLib  = std::vector<bool>(),
+                 bool        ignoreNan       = true,
                  int         generateSteps   = 0,
                  bool        generateLibrary = false,
                  bool        parameterList   = false );
 
-
 // 4) DataFrame with external solver object, init to default SVD
 SMapValues SMap( DataFrame< double > &dataFrameIn,
                  std::string pathOut         = "./",
@@ -176,14 +177,14 @@ SMapValues SMap( DataFrame< double > &dataFrameIn,
                  std::string columns         = "",
                  std::string target          = "",
                  std::string smapFile        = "",
-                 std::string derivatives     = "",
-                 std::valarray< double > (*solver)
-                     (DataFrame     < double >,
-                      std::valarray < double >) = & SVD,
+                 std::string smapSVFile      = "",
+                 SVDValues  (*solver) (DataFrame     < double >,
+                                       std::valarray < double >) = & SVD,
                  bool        embedded        = false,
                  bool        const_predict   = false,
                  bool        verbose         = true,
                  std::vector<bool> validLib  = std::vector<bool>(),
+                 bool        ignoreNan       = true,
                  int         generateSteps   = 0,
                  bool        generateLibrary = false,
                  bool        parameterList   = false );
